==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/QFilterKey.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Storage for filter keys and their values</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html">Qt3DRender::QFilterKey</a></p>
 */
public class QFilterKey extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFilterKey.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::nameChanged(QString)</a></p>
     */
    @QtPropertyNotify(name="name")
    public final @NonNull Signal1<java.lang.@NonNull String> nameChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::valueChanged(QVariant)</a></p>
     */
    @QtPropertyNotify(name="value")
    public final @NonNull Signal1<java.lang.Object> valueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QFilterKey(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFilterKey() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QFilterKey(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFilterKey instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #name()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getName() {
        return name();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::name()const</a></p>
     */
    @QtPropertyReader(name="name")
    @QtUninvokable
    public final java.lang.@NonNull String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::setName(QString)</a></p>
     */
    @QtPropertyWriter(name="name")
    public final void setName(java.lang.@NonNull String customType){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customType);
    }
    
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String customType);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::setValue(QVariant)</a></p>
     */
    @QtPropertyWriter(name="value")
    public final void setValue(java.lang.Object value){
        setValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #value()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.Object getValue() {
        return value();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::value()const</a></p>
     */
    @QtPropertyReader(name="value")
    @QtUninvokable
    public final java.lang.Object value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QFilterKey(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QFilterKey(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFilterKey instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.2-sources.jar: io/qt/qt3d/render/QFilterKey.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Storage for filter keys and their values</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html">Qt3DRender::QFilterKey</a></code></p>
 */
public class QFilterKey extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFilterKey.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::<wbr>nameChanged(QString)</a></code></p>
     */
    @QtPropertyNotify(name="name")
    public final @NonNull Signal1<java.lang.@NonNull String> nameChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::<wbr>valueChanged(QVariant)</a></code></p>
     */
    @QtPropertyNotify(name="value")
    public final @NonNull Signal1<java.lang.Object> valueChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QFilterKey(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFilterKey() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <code>Qt3DRender::QFilterKey::<wbr>QFilterKey(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QFilterKey(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFilterKey instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #name()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getName() {
        return name();
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::<wbr>name()const</a></code></p>
     */
    @QtPropertyReader(name="name")
    @QtUninvokable
    public final java.lang.@NonNull String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#name-prop">Qt3DRender::QFilterKey::<wbr>setName(QString)</a></code></p>
     */
    @QtPropertyWriter(name="name")
    public final void setName(java.lang.@NonNull String customType){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customType);
    }
    
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String customType);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::<wbr>setValue(QVariant)</a></code></p>
     */
    @QtPropertyWriter(name="value")
    public final void setValue(java.lang.Object value){
        setValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #value()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.Object getValue() {
        return value();
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qfilterkey.html#value-prop">Qt3DRender::QFilterKey::<wbr>value()const</a></code></p>
     */
    @QtPropertyReader(name="value")
    @QtUninvokable
    public final java.lang.Object value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QFilterKey(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QFilterKey(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFilterKey instance, QDeclarativeConstructor constructor);
    
}
